Properties Methods Events Config Options Direct Link

# Class Ext.ux.grid.BufferView

Package: | Ext.ux.grid
Defined In: | BufferView.js
Class: | BufferView
Extends: | Object

A custom GridView which renders rows on an as-needed basis.

## Config Options

Config Options | Defined By
--- | ---
| borderHeight : Number The combined height of border-top and border-bottom of a row. | BufferView
| borderHeight : Number The combined height of border-top and border-bottom of a row. | BufferView
| cacheSize : Number The number of rows to look forward and backwards from the currently viewable area. The cache applies only to rows th... The number of rows to look forward and backwards from the currently viewable area. The cache applies only to rows that have been rendered already. | BufferView
| cacheSize : Number The number of rows to look forward and backwards from the currently viewable area. The cache applies only to rows th... The number of rows to look forward and backwards from the currently viewable area. The cache applies only to rows that have been rendered already. | BufferView
| cleanDelay : Number The number of milliseconds to buffer cleaning of extra rows not in the cache. | BufferView
| cleanDelay : Number The number of milliseconds to buffer cleaning of extra rows not in the cache. | BufferView
| rowHeight : Number The height of a row in the grid. | BufferView
| rowHeight : Number The height of a row in the grid. | BufferView
| scrollDelay : Boolean/Number The number of milliseconds before rendering rows out of the visible viewing area. Defaults to 100. Rows will render i... The number of milliseconds before rendering rows out of the visible viewing area. Defaults to 100. Rows will render immediately with a config of false. | BufferView
| scrollDelay : Boolean/Number The number of milliseconds before rendering rows out of the visible viewing area. Defaults to 100. Rows will render i... The number of milliseconds before rendering rows out of the visible viewing area. Defaults to 100. Rows will render immediately with a config of false. | BufferView

## Public Properties

This class has no public properties.

## Public Methods

This class has no public methods.

## Public Events

This class has no public events.